==> react-tcf-first-layer-1.9.0.tgz: package/lib/index.js <==
import _regeneratorRuntime from "@babel/runtime/regenerator";
import _asyncToGenerator from "@babel/runtime/helpers/esm/asyncToGenerator";
import React, { useState, useEffect, useRef, useCallback } from 'react';
import SuiButton from '@s-ui/react-atom-button';
import SuiModal from '@s-ui/react-molecule-modal';
import SuiNotification from '@s-ui/react-molecule-notification';
import IconClose from './iconClose';
import { I18N, ADEVINTA_COLLECTED_CONSENTS } from './settings';
var CLASS = 'sui-TcfFirstLayer';
var SCROLL_TO_ACCEPT = 250;
export default function TcfFirstLayer(_ref) {
  var _ref$lang = _ref.lang,
      lang = _ref$lang === void 0 ? 'es' : _ref$lang,
      logo = _ref.logo,
      isMobile = _ref.isMobile,
      getVendorList = _ref.getVendorList,
      loadUserConsent = _ref.loadUserConsent,
      saveUserConsent = _ref.saveUserConsent,
      openSecondLayer = _ref.openSecondLayer,
      openCookiepolicyLayer = _ref.openCookiepolicyLayer,
      _ref$showInModalForMo = _ref.showInModalForMobile,
      showInModalForMobile = _ref$showInModalForMo === void 0 ? false : _ref$showInModalForMo;

  var _useState = useState(true),
      show = _useState[0],
      setShow = _useState[1];

  var i18n = I18N[lang];
  var handleCookiePolicyLayerClick = useCallback(function () {
    cookiesPolicyLink.current && cookiesPolicyLink.current.removeEventListener('click', handleCookiePolicyLayerClick);
    openCookiepolicyLayer();
  });
  var cookiesPolicyLink = useRef();
  var ref = useRef(null);
  var textRef = useCallback(function (node) {
    if (ref.current) {
      ref.current = null;
    }

    if (node) {
      cookiesPolicyLink.current = node.querySelector("." + CLASS + "-link");

      if (cookiesPolicyLink) {
        cookiesPolicyLink.current.addEventListener('click', handleCookiePolicyLayerClick);
      }

      ref.current = node;
    }
  }, [handleCookiePolicyLayerClick]);
  var initialYOffset;

  var checkScroll = function checkScroll() {
    if (initialYOffset - window.pageYOffset >= SCROLL_TO_ACCEPT || initialYOffset - window.pageYOffset <= -SCROLL_TO_ACCEPT) {
      handleSaveExitClick();
    }
  };

  useEffect(function () {
    initialYOffset = window.pageYOffset;
    document.addEventListener('scroll', checkScroll, {
      passive: true
    });
  }, []);

  var handleSettingsClick = function handleSettingsClick() {
    openSecondLayer();
  };

  var handleSaveExitClick = /*#__PURE__*/function () {
    var _ref2 = _asyncToGenerator( /*#__PURE__*/_regeneratorRuntime.mark(function _callee() {
      var _yield$getVendorList, VLPurposes, VLVendors, VLSpecialFeatures, _yield$loadUserConsen, purpose, vendor, specialFeatures, key;

      return _regeneratorRuntime.wrap(function _callee$(_context) {
        while (1) {
          switch (_context.prev = _context.next) {
            case 0:
              _context.next = 2;
              return getVendorList({
                language: lang
              });

            case 2:
              _yield$getVendorList = _context.sent;
              VLPurposes = _yield$getVendorList.purposes;
              VLVendors = _yield$getVendorList.vendors;
              VLSpecialFeatures = _yield$getVendorList.specialFeatures;
              _context.next = 8;
              return loadUserConsent();

            case 8:
              _yield$loadUserConsen = _context.sent;
              purpose = _yield$loadUserConsen.purpose;
              vendor = _yield$loadUserConsen.vendor;
              specialFeatures = _yield$loadUserConsen.specialFeatures;
              ADEVINTA_COLLECTED_CONSENTS.purposes.forEach(function (index) {
                if (VLPurposes[index]) {
                  purpose.consents[index] = true;
                  purpose.legitimateInterests[index] = true;
                }
              });
              ADEVINTA_COLLECTED_CONSENTS.specialFeatures.forEach(function (index) {
                if (VLSpecialFeatures[index]) {
                  specialFeatures[index] = true;
                }
              });

              for (key in VLVendors) {
                vendor.consents[key] = true;
                vendor.legitimateInterests[key] = true;
              }

              handleCloseModal();
              saveUserConsent({
                purpose: purpose,
                vendor: vendor,
                specialFeatures: specialFeatures
              });

            case 17:
            case "end":
              return _context.stop();
          }
        }
      }, _callee);
    }));

    return function handleSaveExitClick() {
      return _ref2.apply(this, arguments);
    };
  }();

  var handleCloseModal = function handleCloseModal() {
    document.removeEventListener('scroll', checkScroll);
    setShow(false);
  };

  var Content = function Content() {
    return /*#__PURE__*/React.createElement("div", {
      className: CLASS + "-body"
    }, /*#__PURE__*/React.createElement("div", {
      className: CLASS + "-info",
      ref: textRef,
      dangerouslySetInnerHTML: {
        __html: i18n.BODY
      }
    }), /*#__PURE__*/React.createElement("div", {
      className: CLASS + "-buttons"
    }, /*#__PURE__*/React.createElement(SuiButton, {
      onClick: handleSettingsClick,
      design: "outline"
    }, i18n.CONFIGURE_BUTTON), /*#__PURE__*/React.createElement(SuiButton, {
      onClick: handleSaveExitClick
    }, i18n.CONTINUE_NAVIGATION_BUTTON)));
  };

  return /*#__PURE__*/React.createElement("div", {
    className: CLASS
  }, isMobile && showInModalForMobile ? /*#__PURE__*/React.createElement(SuiModal, {
    isOpen: show,
    closeOnOutsideClick: true,
    closeOnEscKeyDown: true,
    header: /*#__PURE__*/React.createElement("img", {
      className: CLASS + "-logo",
      src: logo,
      alt: "logo"
    }),
    iconClose: /*#__PURE__*/React.createElement(IconClose, {
      "class": CLASS + "-icon-close"
    }),
    onClose: handleCloseModal,
    fitContent: true
  }, /*#__PURE__*/React.createElement(Content, null)) : /*#__PURE__*/React.createElement("div", {
    className: CLASS + "-notification " + (isMobile ? CLASS + "--isMobile" : '')
  }, /*#__PURE__*/React.createElement(SuiNotification, {
    position: "bottom",
    autoClose: "manual",
    show: show,
    showCloseButton: false,
    variation: "positive",
    type: "system"
  }, /*#__PURE__*/React.createElement(Content, null))));
}
TcfFirstLayer.displayName = 'TcfFirstLayer';

==> react-tcf-first-layer-1.10.0.tgz: package/lib/index.js <==
import _regeneratorRuntime from "@babel/runtime/regenerator";
import _asyncToGenerator from "@babel/runtime/helpers/esm/asyncToGenerator";
import React, { useState, useEffect, useRef, useCallback } from 'react';
import SuiButton from '@s-ui/react-atom-button';
import SuiModal from '@s-ui/react-molecule-modal';
import SuiNotification from '@s-ui/react-molecule-notification';
import IconClose from './iconClose';
import { I18N, ADEVINTA_COLLECTED_CONSENTS } from './settings';
var CLASS = 'sui-TcfFirstLayer';
var SCROLL_TO_ACCEPT = 250;
export default function TcfFirstLayer(_ref) {
  var _ref$lang = _ref.lang,
      lang = _ref$lang === void 0 ? 'es' : _ref$lang,
      logo = _ref.logo,
      isMobile = _ref.isMobile,
      getVendorList = _ref.getVendorList,
      loadUserConsent = _ref.loadUserConsent,
      saveUserConsent = _ref.saveUserConsent,
      openSecondLayer = _ref.openSecondLayer,
      openCookiepolicyLayer = _ref.openCookiepolicyLayer,
      _ref$showInModalForMo = _ref.showInModalForMobile,
      showInModalForMobile = _ref$showInModalForMo === void 0 ? false : _ref$showInModalForMo;

  var _useState = useState(true),
      show = _useState[0],
      setShow = _useState[1];

  var i18n = I18N[lang];
  var handleCookiePolicyLayerClick = useCallback(function () {
    cookiesPolicyLink.current && cookiesPolicyLink.current.removeEventListener('click', handleCookiePolicyLayerClick);
    openCookiepolicyLayer();
  });
  var cookiesPolicyLink = useRef();
  var ref = useRef(null);
  var textRef = useCallback(function (node) {
    if (ref.current) {
      ref.current = null;
    }

    if (node) {
      cookiesPolicyLink.current = node.querySelector("." + CLASS + "-link");

      if (cookiesPolicyLink) {
        cookiesPolicyLink.current.addEventListener('click', handleCookiePolicyLayerClick);
      }

      ref.current = node;
    }
  }, [handleCookiePolicyLayerClick]);
  var initialYOffset;

  var checkScroll = function checkScroll() {
    if (initialYOffset - window.pageYOffset >= SCROLL_TO_ACCEPT || initialYOffset - window.pageYOffset <= -SCROLL_TO_ACCEPT) {
      handleSaveExitClick();
    }
  };

  useEffect(function () {
    initialYOffset = window.pageYOffset;
    document.addEventListener('scroll', checkScroll, {
      passive: true
    });
  }, []);

  var handleSettingsClick = function handleSettingsClick() {
    openSecondLayer();
  };

  var handleSaveExitClick = /*#__PURE__*/function () {
    var _ref2 = _asyncToGenerator( /*#__PURE__*/_regeneratorRuntime.mark(function _callee() {
      var _yield$getVendorList, VLPurposes, VLVendors, VLSpecialFeatures, _yield$loadUserConsen, purpose, vendor, specialFeatures, key;

      return _regeneratorRuntime.wrap(function _callee$(_context) {
        while (1) {
          switch (_context.prev = _context.next) {
            case 0:
              _context.next = 2;
              return getVendorList({
                language: lang
              });

            case 2:
              _yield$getVendorList = _context.sent;
              VLPurposes = _yield$getVendorList.purposes;
              VLVendors = _yield$getVendorList.vendors;
              VLSpecialFeatures = _yield$getVendorList.specialFeatures;
              _context.next = 8;
              return loadUserConsent();

            case 8:
              _yield$loadUserConsen = _context.sent;
              purpose = _yield$loadUserConsen.purpose;
              vendor = _yield$loadUserConsen.vendor;
              specialFeatures = _yield$loadUserConsen.specialFeatures;
              ADEVINTA_COLLECTED_CONSENTS.purposes.forEach(function (index) {
                if (VLPurposes[index]) {
                  purpose.consents[index] = true;
                  purpose.legitimateInterests[index] = true;
                }
              });
              ADEVINTA_COLLECTED_CONSENTS.specialFeatures.forEach(function (index) {
                if (VLSpecialFeatures[index]) {
                  specialFeatures[index] = true;
                }
              });

              for (key in VLVendors) {
                vendor.consents[key] = true;
                vendor.legitimateInterests[key] = true;
              }

              handleCloseModal();
              saveUserConsent({
                purpose: purpose,
                vendor: vendor,
                specialFeatures: specialFeatures
              });

            case 17:
            case "end":
              return _context.stop();
          }
        }
      }, _callee);
    }));

    return function handleSaveExitClick() {
      return _ref2.apply(this, arguments);
    };
  }();

  var handleCloseModal = function handleCloseModal() {
    document.removeEventListener('scroll', checkScroll);
    setShow(false);
  };

  var Content = function Content() {
    return /*#__PURE__*/React.createElement("div", {
      className: CLASS + "-body"
    }, /*#__PURE__*/React.createElement("div", {
      className: CLASS + "-info",
      ref: textRef,
      dangerouslySetInnerHTML: {
        __html: i18n.BODY
      }
    }), /*#__PURE__*/React.createElement("div", {
      className: CLASS + "-buttons"
    }, /*#__PURE__*/React.createElement(SuiButton, {
      onClick: handleSettingsClick,
      design: "outline"
    }, i18n.CONFIGURE_BUTTON), /*#__PURE__*/React.createElement(SuiButton, {
      onClick: handleSaveExitClick
    }, i18n.CONTINUE_NAVIGATION_BUTTON)));
  };

  return /*#__PURE__*/React.createElement("div", {
    className: CLASS
  }, isMobile && showInModalForMobile ? /*#__PURE__*/React.createElement(SuiModal, {
    isOpen: show,
    closeOnOutsideClick: true,
    closeOnEscKeyDown: true,
    header: /*#__PURE__*/React.createElement("img", {
      className: CLASS + "-logo",
      src: logo,
      alt: "logo"
    }),
    iconClose: /*#__PURE__*/React.createElement(IconClose, {
      "class": CLASS + "-icon-close"
    }),
    onClose: handleSaveExitClick,
    fitContent: true
  }, /*#__PURE__*/React.createElement(Content, null)) : /*#__PURE__*/React.createElement("div", {
    className: CLASS + "-notification " + (isMobile ? CLASS + "--isMobile" : '')
  }, /*#__PURE__*/React.createElement(SuiNotification, {
    position: "bottom",
    autoClose: "manual",
    show: show,
    showCloseButton: false,
    variation: "positive",
    type: "system"
  }, /*#__PURE__*/React.createElement(Content, null))));
}
TcfFirstLayer.displayName = 'TcfFirstLayer';
